@@ -250,6 +250,7 @@ def cli(cli_args=sys.argv[1:]):
         editorContentParts.append(
             f"""
 # starts line {lineStart} in {sourceFile}
+
 {transactionSource}
 # ends line {lineEnd} in {sourceFile}
 """.strip()
@@ -334,6 +335,8 @@ def cli(cli_args=sys.argv[1:]):
                         print_content()
                     else:
                         lineEnd = int(g["line"])
+                        if not next(iter(newContentLines), True):
+                            newContentLines.pop(0)  # remove initial empty line
                         yield sourceFile, lineStart, lineEnd, os.linesep.join(
                             newContentLines
                         )
