@@ -94,3 +94,50 @@ def splitlines(s, linesep=os.linesep):
     Proper version of :any:`str.splitlines` that round-trips with ``linesep.join(s)``.
     """
     return (s + linesep).splitlines()
+
+
+def is_iterable(x):
+    """
+    Check if a given object is iterable but not a string.
+    """
+    if isinstance(x, str):
+        return False
+    try:
+        iter(x)
+    except TypeError:
+        return False
+    return True
+
+
+def iter_(x):
+    """
+    Like :any:`iter` but yield uniterable objects instead of raising a
+    :any:`TypeError`.
+    """
+    if isinstance(x, str):
+        yield x
+    try:
+        yield from x
+    except TypeError:
+        yield x
+
+
+def flatten(*sequences):
+    """
+    Flatten given sequence(s)
+    """
+    if len(sequences) > 1:
+        for sequence in sequences:
+            yield from flatten(sequence)
+    else:
+        sequence = next(iter_(sequences), tuple())
+        if isinstance(sequence, str):
+            yield sequence
+        try:
+            for element in sequence:
+                if is_iterable(element):
+                    yield from flatten(element)
+                else:
+                    yield element
+        except TypeError:
+            yield sequence
